@@ -906,8 +906,8 @@ def pulse_fraction_from_data_rms(counts, counts_err, n_harm=-1, background=None,
 
     Returns:
         numppy double: pulsed fraction
-    """   
-
+    """
+    from matplotlib import cm
     a0 = np.mean(counts)
 
     N = np.size(counts)
@@ -977,19 +977,23 @@ def pulse_fraction_from_data_rms(counts, counts_err, n_harm=-1, background=None,
 
     PF_rms = np.sqrt(2 * sum(bla)) / a0
 
+
+    col = cm.viridis(np.linspace(0, 1,int(500)))
     if plot:
         import matplotlib.pyplot as plt
-        #plt.figure()
         f = np.linspace(0, 1, int(N))
         if n_harm > 1:
-            plt.errorbar(f, counts, yerr=counts_err, marker='.', label='data %s' % label, linestyle='')
+            plt.errorbar(f, counts, yerr=counts_err, fmt='.',color=col[n_harm])
+            plt.plot(f, counts, linestyle='--', color=col[n_harm])
         else:
-            plt.plot(np.arange(1,K+1), cumulative_sum - m4, label='data %s' % label)
-        #plt.plot(f, y, label='%d harmonics' % n_harm, linestyle='--')
+            plt.plot(np.arange(1,K+1), cumulative_sum - m4, color = col[max_harm])
+        #plt.text(0.4,120,str(n_harm)+'  harmonics',color = col[n_harm])
         plt.xlabel('Phase')
-        plt.legend()
+        plt.ylabel('Counts')
+        #plt.legend()
         if label != '':
             plt.savefig('rms_%s.pdf' % label)
+
     if verbose:
         return PF_rms, max_harm
     else:
@@ -1066,11 +1070,11 @@ def get_pulsed_fraction(e_min, e_max, pp, dpp, method_calc_rms='adaptive', outpu
             dpulsed_frac[i] = get_error_from_simul(x,dx, pulse_fraction_from_data_rms, n_harm=3)
         else:
         #RMS with adaptive n_harm
-            # print(e_min[i], e_max[i])
+            ## print(e_min[i], e_max[i])
             pulsed_frac[i] = fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, n_harm_max=8, plot=False)
             dpulsed_frac[i] = get_error_from_simul(x,dx, fft_pulsed_fraction, level=0.1, n_harm_min=2, 
                                                          n_harm_max=8, verbose=False,  n_simul=300)
-        
+            #
     if output_file is not None:
         with open(output_file, 'w') as ff:
             ff.write("Energy Energy_error Pulsed_fraction Pulsed_fraction_Error\n")
@@ -1308,7 +1312,7 @@ def elaborate_pulsed_fraction(ee_pulsed, dee_pulsed, pulsed_frac, dpulsed_frac,
         comps_high = pulsed_fit_high.eval_components(x=ee_pulsed[ind_high])
         bb_high = (pulsed_frac[ind_high] - pulsed_fit_high.best_fit) / dpulsed_frac[ind_high]
 
-    col = cm.viridis(np.linspace(0, 1, 6))
+    col =cm.viridis(np.linspace(0, 1, 6))
 
     fig, (ax1, ax2) = plt.subplots(2, 1, figsize=(6.2, 6.0), sharex=True, gridspec_kw={'height_ratios': [3, 1],
                                                                         'hspace': 0.0}
@@ -1645,7 +1649,7 @@ def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, n_harm_max=-1, plot=Fals
     :param dx: pulse profile uncertainty
     :param level: confidence level for chi^2 test to stop number of harmonics (default 0.1)
     :param n_harm_min: minimum number of harmonics to use (default 2)
-    :param n_harm_max: minimum number of harmonics to use (default -1 takes the size of pulse profile)
+    :param n_harm_max: maximum number of harmonics to use (default -1 takes the size of pulse profile)
     :param plot: plot the pulse profile
     :param lavel: to save the plot with name "rms_`label`.pdf", if label=='' it does not save the plot
     ;parma verbose (bool): if true it returns both pulsed_frac, n_harm, if false just the pulsed_frac
@@ -1655,6 +1659,7 @@ def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, n_harm_max=-1, plot=Fals
     '''
     # import scipy.stats.chisquare as chi2
     from scipy.stats import chi2
+    from matplotlib import cm
     n = len(x)
 
     if n_harm_max < n_harm_min or n_harm_max+1 > n/2:
@@ -1690,15 +1695,18 @@ def fft_pulsed_fraction(x, dx, level=0.1, n_harm_min=2, n_harm_max=-1, plot=Fals
         a[0] = subtract_background(a[0], background,background_error)
     
     pulsed_frac = np.sqrt(np.sum(a[1:n_harm] ** 2) + np.sum(a[-n_harm + 1:] ** 2)) / a[0]
-
+    col = cm.viridis(np.linspace(0, 1,int(n_harm_max)+1))
     if plot:
         import matplotlib.pyplot as plt
-        #plt.figure()
         f = np.linspace(0, 1, n)
-        plt.errorbar(f, x, yerr=dx, marker='.', label='data %s' % label, linestyle='')
-        plt.plot(f, y, label='%d harmonics' % n_harm, linestyle='--')
+        #plt.errorbar(f, x, yerr=dx, fmt='.', label='data %s' % label, color = col[n_harm])
+        #plt.plot(f, y, label='%d harmonics' % n_harm, linestyle='--', color = col[n_harm])
+        plt.errorbar(f, x, yerr=dx, fmt='.', color=col[n_harm])
+        plt.plot(f, y, linestyle='--', color=col[n_harm])
+        #plt.text(0.4,120,str(n_harm)+'  harmonics',color = col[n_harm])
         plt.xlabel('Phase')
-        plt.legend()
+        plt.ylabel('Counts')
+        #plt.legend()
         if label != '':
             plt.savefig('rms_%s.pdf' % label)
     if verbose:
@@ -1731,6 +1739,7 @@ def pulse_fraction_from_data_min_max(x,dx):
 
     return pulsed_frac, dpulsed_frac
 import matplotlib.cm
+
 def plot_matrix_as_image(ee, pp, kind='E', normalize=True,outfile=None, cmap=matplotlib.cm.gist_earth,
                          sliders=False, n_levels=30, min_level=None, max_level=None, source_name=None):
     '''
